==> piwigo-2.7.4.zip: piwigo/plugins/TakeATour/language/sl_SI/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Pozdravljeni v predstavitvi galerije!!<br>
Tu so prikazane vse razpoložljive predstavitve preko katerih lahko spoznate značilnosti vaše galerije Piwigo. <br> Izberite eno od spodnjih predstavitev, nato pa sledite navodilom. Kliknite Naprej / Nazaj (ali uporabite puščice na tipkovnici) za navigacijo med predstavitvijo.<br>Če greste med predstavitvijo na drugo stran administracije, boste preusmerjeni na trenuto stran predstavitve. Če ste obtičali in ne more končati predstavitve, pojdite na <em>Vtičniki >> Začni predtavitev</ em>! S tem boste končali predstavitev.';
$lang['Start the Tour'] = 'Prični s Predstavitvijo';
$lang['Prev'] = 'Nazaj';
$lang['Next '] = 'Naprej';
$lang['End tour'] = 'Konec predstavitve';

$lang['First Contact'] = 'Prvi Kontakt';

$lang['2.7 Tour'] = '2.7 Predstavitev';
$lang['2_7_0_descrp'] = 'Odkrijte kaj je novega v Piwigo 2.7';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Oglejte si predstavitev in odkrijte značilnosti galerije Piwigo » Pojdite na predstavitve ki so na voljo';
$lang['Privacy'] = 'Zasebnost';
$lang['Visit your Piwigo!'] = 'Oglejte si vaš Piwigo!';
$lang['takeatour_configpage'] = 'Začni predtavitev';
$lang['privacy_descrp'] = 'Ta predstavitev vam prikaže vse možnosti zaščite fotografij pred javnim dostopom s pomočjo nastavitev pravic po Albumih in po fotografijah in zaščito pred kopiranjem z uporabo zaščite fotografij ';
$lang['first_contact_descrp'] = 'Ta predstavitev je namenjena začetnikom, predstavi vam osnovne lastnosti Piwigo galerije in se prične s predstavitvijo kako dodati fotografije in jih nato upravljati. Predstavitev se nadaljuje z upravljanjem Albumov in se konča s predstavitvijo prilagajanja Piwigo z uporabo Konfiguracije, spreminjanje izgleda (Teme) in uporabo Vtičnikov.';

==> piwigo-15.6.0.zip: piwigo/plugins/TakeATour/language/sl_SI/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Pozdravljeni v predstavitvi galerije!!<br>
Tu so prikazane vse razpoložljive predstavitve preko katerih lahko spoznate značilnosti vaše galerije Piwigo. <br> Izberite eno od spodnjih predstavitev, nato pa sledite navodilom. Kliknite Naprej / Nazaj (ali uporabite puščice na tipkovnici) za navigacijo med predstavitvijo.<br>Če greste med predstavitvijo na drugo stran administracije, boste preusmerjeni na trenuto stran predstavitve. Če ste obtičali in ne more končati predstavitve, pojdite na <em>Vtičniki >> Začni predtavitev</ em>! S tem boste končali predstavitev.';
$lang['Start the Tour'] = 'Prični s Predstavitvijo';
$lang['Prev'] = 'Nazaj';
$lang['Next '] = 'Naprej';
$lang['End tour'] = 'Konec predstavitve';

$lang['First Contact'] = 'Prvi Kontakt';

$lang['2.7 Tour'] = '2.7 Predstavitev';
$lang['2_7_0_descrp'] = 'Odkrijte kaj je novega v Piwigo 2.7';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Oglejte si predstavitev in odkrijte značilnosti galerije Piwigo » Pojdite na predstavitve ki so na voljo';
$lang['Privacy'] = 'Zasebnost';
$lang['Visit your Piwigo!'] = 'Oglejte si vaš Piwigo!';
$lang['takeatour_configpage'] = 'Začni predtavitev';
$lang['privacy_descrp'] = 'Ta predstavitev vam prikaže vse možnosti zaščite fotografij pred javnim dostopom s pomočjo nastavitev pravic po Albumih in po fotografijah in zaščito pred kopiranjem z uporabo zaščite fotografij.';
$lang['first_contact_descrp'] = 'Ta predstavitev je namenjena začetnikom, predstavi vam osnovne lastnosti Piwigo galerije in se prične s predstavitvijo kako dodati fotografije in jih nato upravljati. Predstavitev se nadaljuje z upravljanjem Albumov in se konča s predstavitvijo prilagajanja Piwigo z uporabo Konfiguracije, spreminjanje izgleda (Teme) in uporabo Vtičnikov.';
$lang['2.8 Tour'] = '2.8 Predstavitev';
$lang['2_8_0_descrp'] = 'Odkrijte nekatere novosti Piwigo 2.8. Preberite podrobnosti v <a href="%s">opambah ob izdaji</a>.';
$lang['config_descrp'] = 'Konfiguracija vaših Piwigo nastavitev. Odkrijte upravitelja preoblek in izberite videz vaše Piwigo galerije';
$lang['config_name'] = 'Konfiguracija';
$lang['edit_photos_descrp'] = 'Slike so osnovni element v vaši Piwigo galeriji. Poglejte si, kako lahko spremenite lastnosti slik za posamično sliko ali za skupino slik';
$lang['edit_photos_name'] = 'Uredi slike';
$lang['manage_albums_descrp'] = 'Hierarhija vaših albumov je struktura vaše galerije. Naučite se kako jih organizirati in urediti njihove lastnosti';
$lang['manage_albums_name'] = 'Upravljanje Albumov';
$lang['plugins_descrp'] = 'Vtičniki so ključna značilnost v Piwigo. Aktivirajte različne funkcije z nekaj kliki in si s tem prilagodite delovanje Piwigo tako kot vam ustreza.';
$lang['plugins_name'] = 'Vtičniki';
$lang['2_9_0_descrp'] = 'Odkrijte nove možnosti v Piwigo 2.9. Podrobnosti preberite na  <a href="%s">opombe ob izdaji</a>.';
$lang['2_9_0_name'] = 'Ogled verzije 2.9';
